==> tabular-data-gwt-service-2.5.1-20141210.173742-1-sources.jar: org/gcube/portlets/user/td/gwtservice/shared/tr/replacebyexternal/ReplaceByExternalColumnsMapping.java <==
package org.gcube.portlets.user.td.gwtservice.shared.tr.replacebyexternal;

import java.io.Serializable;

import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;

/**
 * 
 * @author "Giancarlo Panichi" email: <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 *
 */
public class ReplaceByExternalColumnsMapping implements Serializable {

	private static final long serialVersionUID = 2795844498148679703L;

	protected String columnLabel;
	protected ColumnData currentColumn;
	protected ColumnData externalColumn;

	public ReplaceByExternalColumnsMapping() {

	}
	
	/**
	 * 
	 * @param columnLabel
	 * @param currentColumn
	 * @param externalColumn
	 */
	public ReplaceByExternalColumnsMapping(String columnLabel,
			ColumnData currentColumn, ColumnData externalColumn) {
		super();
		this.columnLabel = columnLabel;
		this.currentColumn = currentColumn;
		this.externalColumn = externalColumn;
	}

	public String getColumnLabel() {
		return columnLabel;
	}

	public void setColumnLabel(String columnLabel) {
		this.columnLabel = columnLabel;
	}

	public ColumnData getCurrentColumn() {
		return currentColumn;
	}

	public void setCurrentColumn(ColumnData currentColumn) {
		this.currentColumn = currentColumn;
	}

	public ColumnData getExternalColumn() {
		return externalColumn;
	}

	public void setExternalColumn(ColumnData externalColumn) {
		this.externalColumn = externalColumn;
	}

	@Override
	public String toString() {
		return "ReplaceByExternalColumnsMapping [columnLabel=" + columnLabel
				+ ", currentColumn=" + currentColumn + ", externalColumn="
				+ externalColumn + "]";
	}

	
}

==> tabular-data-gwt-service-2.7.0-20150623.082808-158-sources.jar: org/gcube/portlets/user/td/gwtservice/shared/tr/replacebyexternal/ReplaceByExternalColumnsMapping.java <==
package org.gcube.portlets.user.td.gwtservice.shared.tr.replacebyexternal;

import java.io.Serializable;

import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnData;

/**
 * 
 * @author "Giancarlo Panichi" email: <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 *
 */
public class ReplaceByExternalColumnsMapping implements Serializable {

	private static final long serialVersionUID = 2795844498148679703L;

	protected String columnLabel;
	protected ColumnData currentColumn;
	protected ColumnData externalColumn;

	public ReplaceByExternalColumnsMapping() {

	}
	
	/**
	 * 
	 * @param columnLabel
	 * @param currentColumn
	 * @param externalColumn
	 */
	public ReplaceByExternalColumnsMapping(String columnLabel,
			ColumnData currentColumn, ColumnData externalColumn) {
		super();
		this.columnLabel = columnLabel;
		this.currentColumn = currentColumn;
		this.externalColumn = externalColumn;
	}

	public String getColumnLabel() {
		return columnLabel;
	}

	public void setColumnLabel(String columnLabel) {
		this.columnLabel = columnLabel;
	}

	public ColumnData getCurrentColumn() {
		return currentColumn;
	}

	public void setCurrentColumn(ColumnData currentColumn) {
		this.currentColumn = currentColumn;
	}

	public ColumnData getExternalColumn() {
		return externalColumn;
	}

	public void setExternalColumn(ColumnData externalColumn) {
		this.externalColumn = externalColumn;
	}

	@Override
	public String toString() {
		return "ReplaceByExternalColumnsMapping [columnLabel=" + columnLabel
				+ ", currentColumn=" + currentColumn + ", externalColumn="
				+ externalColumn + "]";
	}

	
}
